@@ -1,10 +1,13 @@
 /* -----------------------------------------------------------------
- * Programmer(s): Daniel Reynolds, Ashley Crawford @ SMU
- * Based on sundials_pcg.c code, written by Daniel Reynolds @ SMU
+ * Programmer(s): Daniel Reynolds, Ashley Crawford @ UMBC
+ * Based on sundials_pcg.c code, written by Daniel Reynolds @ UMBC
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2025, Lawrence Livermore National Security
+ * Copyright (c) 2025, Lawrence Livermore National Security,
+ * University of Maryland Baltimore County, and the SUNDIALS contributors.
+ * Copyright (c) 2013-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
+ * Copyright (c) 2002-2013, Lawrence Livermore National Security.
  * All rights reserved.
  *
  * See the top-level LICENSE and NOTICE files for details.
@@ -18,12 +21,14 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include <sundials/priv/sundials_errors_impl.h>
 #include <sundials/sundials_math.h>
 #include <sunlinsol/sunlinsol_pcg.h>
-
 #include "sundials_logger_impl.h"
+
+#include "sundials_cli.h"
 #include "sundials_macros.h"
 
 #define ZERO SUN_RCONST(0.0)
@@ -39,6 +44,18 @@
 #define PRETYPE(S)     (PCG_CONTENT(S)->pretype)
 #define LASTFLAG(S)    (PCG_CONTENT(S)->last_flag)
 
+/*
+ * -----------------------------------------------------------------
+ * unexported functions
+ * -----------------------------------------------------------------
+ */
+
+static SUNErrCode setFromCommandLine_PCG(SUNLinearSolver S, const char* LSid,
+                                         int argc, char* argv[]);
+
+SUNErrCode SUNLinSolSetOptions_PCG(SUNLinearSolver S, const char* LSid,
+                                   const char* file_name, int argc, char* argv[]);
+
 /*
  * -----------------------------------------------------------------
  * exported functions
@@ -72,6 +89,7 @@ SUNLinearSolver SUNLinSol_PCG(N_Vector y, int pretype, int maxl, SUNContext sunc
   S->ops->gettype           = SUNLinSolGetType_PCG;
   S->ops->getid             = SUNLinSolGetID_PCG;
   S->ops->setatimes         = SUNLinSolSetATimes_PCG;
+  S->ops->setoptions        = SUNLinSolSetOptions_PCG;
   S->ops->setpreconditioner = SUNLinSolSetPreconditioner_PCG;
   S->ops->setscalingvectors = SUNLinSolSetScalingVectors_PCG;
   S->ops->setzeroguess      = SUNLinSolSetZeroGuess_PCG;
@@ -127,6 +145,85 @@ SUNLinearSolver SUNLinSol_PCG(N_Vector y, int pretype, int maxl, SUNContext sunc
   return (S);
 }
 
+/* ----------------------------------------------------------------------------
+ * Function to control set routines via the command line or file
+ */
+
+SUNErrCode SUNLinSolSetOptions_PCG(SUNLinearSolver S, const char* LSid,
+                                   SUNDIALS_MAYBE_UNUSED const char* file_name,
+                                   int argc, char* argv[])
+{
+  SUNFunctionBegin(S->sunctx);
+
+  /* File-based option control is currently unimplemented */
+  SUNAssert((file_name == NULL || strlen(file_name) == 0),
+            SUN_ERR_ARG_INCOMPATIBLE);
+
+  if (argc > 0 && argv != NULL)
+  {
+    SUNCheckCall(setFromCommandLine_PCG(S, LSid, argc, argv));
+  }
+
+  return SUN_SUCCESS;
+}
+
+/* ----------------------------------------------------------------------------
+ * Function to control set routines via the command line
+ */
+
+static SUNErrCode setFromCommandLine_PCG(SUNLinearSolver S, const char* LSid,
+                                         int argc, char* argv[])
+{
+  SUNFunctionBegin(S->sunctx);
+
+  /* Prefix for options to set */
+  const char* default_id = "sunlinearsolver";
+  size_t offset          = strlen(default_id) + 1;
+  if (LSid != NULL && strlen(LSid) > 0) { offset = strlen(LSid) + 1; }
+  char* prefix = (char*)malloc(sizeof(char) * (offset + 1));
+  if (LSid != NULL && strlen(LSid) > 0) { strcpy(prefix, LSid); }
+  else { strcpy(prefix, default_id); }
+  strcat(prefix, ".");
+
+  for (int idx = 1; idx < argc; idx++)
+  {
+    int retval;
+
+    /* skip command-line arguments that do not begin with correct prefix */
+    if (strncmp(argv[idx], prefix, strlen(prefix)) != 0) { continue; }
+
+    /* control over PrecType function */
+    if (strcmp(argv[idx] + offset, "prec_type") == 0)
+    {
+      idx += 1;
+      int iarg = atoi(argv[idx]);
+      retval   = SUNLinSol_PCGSetPrecType(S, iarg);
+      if (retval != SUN_SUCCESS)
+      {
+        free(prefix);
+        return retval;
+      }
+      continue;
+    }
+
+    /* control over Maxl function */
+    if (strcmp(argv[idx] + offset, "maxl") == 0)
+    {
+      idx += 1;
+      int iarg = atoi(argv[idx]);
+      retval   = SUNLinSol_PCGSetMaxl(S, iarg);
+      if (retval != SUN_SUCCESS)
+      {
+        free(prefix);
+        return retval;
+      }
+      continue;
+    }
+  }
+  free(prefix);
+  return SUN_SUCCESS;
+}
+
 /* ----------------------------------------------------------------------------
  * Function to set the type of preconditioning for PCG to use
  */
